mllRH1: Minus loglikelihood of a RHawkes model with parent probabilities
Description
Calculates the minus loglikelihood of a RHawkes model with given
immigration hazard function \(\mu\), offspring density function
\(h\) and branching ratio \(\eta\) for event times tms
on interval \([0,cens]\). The same as mllRH although this
version also returns the parent probabilities.
A numeric vector, with values sorted in ascending order. Event times
to fit the RHawkes point process model.
cens
A scalar. The censoring time.
par
A numeric vector containing the parameters of the model, in order of the
immigration parameters \(\mu(.)\), offspring parameters \(h(.)\) and
lastly the branching ratio \(\eta(.)\).
h.fn
A (vectorized) function. The offspring density function.
mu.fn
A (vectorized) function. The immigration hazard function.
H.fn
A (vectorized) function. Its value at t gives the integral of
the offspring density function from 0 to t.
Mu.fn
A (vectorized) function. Its value at t gives the integral of
the immigrant hazard function from 0 to t.